@@ -6,8 +6,8 @@ use anyhow::Result;
 use deno_ast::parse_module;
 use deno_ast::swc::common::comments::Comment;
 use deno_ast::swc::common::BytePos;
-use deno_ast::swc::dep_graph::DependencyDescriptor;
-use deno_ast::swc::dep_graph::DependencyKind;
+pub use deno_ast::swc::dep_graph::DependencyDescriptor;
+pub use deno_ast::swc::dep_graph::DependencyKind;
 use deno_ast::Diagnostic;
 use deno_ast::MediaType;
 use deno_ast::ParseParams;
@@ -224,6 +224,8 @@ pub trait SourceParser {
   ) -> Result<ParsedSource, Diagnostic>;
 }
 
+// TODO(@dsherret) remove CapturingSourceParser
+
 /// An implementation of `SourceParser` that stores the parsed ASTs.
 #[derive(Default)]
 pub struct CapturingSourceParser {
